FirstAlexaSkills package
========================

.. Subpackages
.. -----------
..
.. .. toctree::
..
..    FirstAlexaSkills.data

Modules
-------

FirstAlexaSkills.lambda_utils module
------------------------------------

.. automodule:: FirstAlexaSkills.lambda_utils
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: FirstAlexaSkills
    :members:
    :undoc-members:
    :show-inheritance:
